==> apache-camel-3.14.6-src.zip: apache-camel-3.14.6/components/camel-platform-http-vertx/src/test/java/org/apache/camel/component/platform/http/vertx/VertxPlatformHttpJacksonTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.platform.http.vertx;

import org.apache.camel.CamelContext;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.jackson.JacksonConstants;
import org.junit.jupiter.api.Test;

import static io.restassured.RestAssured.given;
import static org.hamcrest.Matchers.equalTo;

public class VertxPlatformHttpJacksonTest {

    @Test
    public void testJackson() throws Exception {
        final CamelContext context = VertxPlatformHttpEngineTest.createCamelContext();

        try {
            // turn on jackson type converter
            context.getGlobalOptions().put(JacksonConstants.ENABLE_TYPE_CONVERTER, "true");

            context.addRoutes(new RouteBuilder() {
                @Override
                public void configure() throws Exception {
                    from("platform-http:/hello")
                            .setBody().constant("{\"hello\": \"world\"}")
                            .unmarshal().json();
                }
            });

            context.start();

            given()
                    .when()
                    .get("/hello")
                    .then()
                    .statusCode(200)
                    .body(equalTo("{\"hello\":\"world\"}"));
        } finally {
            context.stop();
        }
    }

}

==> apache-camel-4.14.1-src.zip: apache-camel-4.14.1/components/camel-platform-http-vertx/src/test/java/org/apache/camel/component/platform/http/vertx/VertxPlatformHttpJacksonTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.platform.http.vertx;

import org.apache.camel.CamelContext;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.component.jackson.JacksonConstants;
import org.junit.jupiter.api.Test;

import static io.restassured.RestAssured.given;
import static org.hamcrest.Matchers.equalTo;

public class VertxPlatformHttpJacksonTest {

    @Test
    public void testJackson() throws Exception {
        final CamelContext context = VertxPlatformHttpEngineTest.createCamelContext();

        try {
            // turn on jackson type converter
            context.getGlobalOptions().put(JacksonConstants.ENABLE_TYPE_CONVERTER, "true");

            context.addRoutes(new RouteBuilder() {
                @Override
                public void configure() {
                    from("platform-http:/hello")
                            .setBody().constant("{\"hello\": \"world\"}")
                            .unmarshal().json();
                }
            });

            context.start();

            given()
                    .when()
                    .get("/hello")
                    .then()
                    .statusCode(200)
                    .body(equalTo("{\"hello\":\"world\"}"));
        } finally {
            context.stop();
        }
    }

}
